#[non_exhaustive]pub struct AuthorizationQueryContext {
pub locator: Option<String>,
pub time: Option<DateTime<Utc>>,
pub extra: HashMap<String, String>,
}Expand description
Optional TRQP query context. time requests evaluation as of a given instant; locator is an authority-defined hint for locating records.
JSON schema
{
"title": "QueryContext",
"description": "Optional TRQP query context. `time` requests evaluation as of a given instant; `locator` is an authority-defined hint for locating records.",
"type": "object",
"properties": {
"locator": {
"description": "Optional hint for systems that need extra information to locate the records in question (authorization queries).",
"type": "string"
},
"time": {
"description": "Evaluate the query as of this RFC3339 (Z offset) instant. Blank/absent uses current server time.",
"type": "string",
"format": "date-time"
}
},
"additionalProperties": {
"type": "string"
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.locator: Option<String>Optional hint for systems that need extra information to locate the records in question (authorization queries).
time: Option<DateTime<Utc>>Evaluate the query as of this RFC3339 (Z offset) instant. Blank/absent uses current server time.
extra: HashMap<String, String>Implementations
Sourceimpl QueryContext
impl QueryContext
pub fn builder() -> QueryContext