pub struct AuthorizationResponse {
pub action: String,
pub authority_id: String,
pub authorized: bool,
pub context: Option<QueryContext>,
pub entity_id: String,
pub ext: Option<Ext>,
pub message: Option<String>,
pub resource: String,
pub time_evaluated: DateTime<Utc>,
pub time_requested: Option<DateTime<Utc>>,
}Expand description
Response
JSON schema
{
"title": "Response",
"type": "object",
"required": [
"action",
"authority_id",
"authorized",
"entity_id",
"resource",
"time_evaluated"
],
"properties": {
"action": {
"type": "string"
},
"authority_id": {
"type": "string"
},
"authorized": {
"description": "True if the action+resource authorization has been confirmed, false otherwise.",
"type": "boolean"
},
"context": {
"$ref": "#/definitions/QueryContext"
},
"entity_id": {
"type": "string"
},
"ext": {
"$ref": "#/definitions/Ext"
},
"message": {
"description": "Additional human-readable detail about the authorization response.",
"type": "string"
},
"resource": {
"type": "string"
},
"time_evaluated": {
"description": "Server time the query was evaluated at, per the endpoint clock.",
"type": "string",
"format": "date-time"
},
"time_requested": {
"description": "The requested server time, echoed from the request `context.time` when supplied.",
"type": "string",
"format": "date-time"
}
},
"additionalProperties": false,
"$anchor": "response"
}Fields
action: StringTrue if the action+resource authorization has been confirmed, false otherwise.
context: Option<QueryContext>entity_id: Stringext: Option<Ext>message: Option<String>Additional human-readable detail about the authorization response.
resource: Stringtime_evaluated: DateTime<Utc>Server time the query was evaluated at, per the endpoint clock.
time_requested: Option<DateTime<Utc>>The requested server time, echoed from the request context.time when supplied.